import { test, Page, expect } from '@playwright/test';
test.describe.configure({ mode: 'serial' });
import * as Helper from '../test_helper.js'

let page: Page;

test.beforeAll(async ({ browser }) => {
  // Create page once.
  page = await browser.newPage();
  await page.goto(Helper.site_url());
  await page.fill("#username", "agileway");
  await page.fill("#password", "testwise");
  await page.click("input:has-text('Sign in')");
});

test.afterAll(async () => {
   await page.close();
});

  
test.beforeEach(async () => {
  await page.goto(Helper.site_url());
});

test.afterEach(async () => {
  if (Helper.is_debugging()) {
    await Helper.sleep(2); // feel free to change wait time here
  }
});


test('User can select one way trip', async () => {  
  await page.locator("//input[@value='oneway']").click();
  await page.locator("select[name='fromPort']").selectOption({ label: 'Sydney' });
  await page.selectOption("select[name='toPort']", { label: 'New York' });
  await page.click("//input[@value='Continue']");
  
  const pageText = await page.textContent("body");
  expect(pageText).toContain("Sydney to New York");
});

test('User can select return trip', async () => {
  await page.locator("//input[@value='return']").click();
  await page.locator("select[name='fromPort']").selectOption({ label: 'Sydney' });
  await page.selectOption("select[name='toPort']", { label: 'New York' });
  await page.locator("#departDay").selectOption({ index: 2 });
  await page.locator("#departMonth").selectOption("032025");
  await page.locator("#returnDay").selectOption({ index: 3 });
  await page.locator("#returnMonth").selectOption("042025");
  await page.click("//input[@value='Continue']");
  
  const pageText = await page.textContent("body");
  expect(pageText).toContain("Sydney to New York");
  expect(pageText).toContain("New York to Sydney");
});


