import { test, Page, expect } from '@playwright/test';
var path = require("path");

test.describe.configure({ mode: 'serial' });

import * as Helper from '../test_helper.js'

//Reuse the page among the test cases in the test script file
let page: Page;

test.beforeAll(async ({ browser }) => {
  // Create page once.
  page = await browser.newPage();
});

test.afterAll(async () => {
   await page.close();
});

  
test.beforeEach(async () => {
  await page.goto(Helper.site_url());
});

test.afterEach(async () => {
  if (Helper.is_debugging()) {
    await Helper.sleep(2); // feel free to change wait time here
  }
});


test('User can enter passenger details', async () => {
  await page.fill("#username", "agileway");
  await page.fill("#password", "testwise");
  await page.click("input:has-text('Sign in')");
  const flashText = await page.textContent("#flash_notice")
  expect(flashText).toEqual('Signed in!');
  
  await page.locator("//input[@value='oneway']").click();
  await page.locator("select[name='fromPort']").selectOption({ label: 'Sydney' });
  await page.selectOption("select[name='toPort']", { label: 'New York' });
  const v = await page.locator("//input[@value='oneway']").isChecked();
  expect(v).toBe(true);
  await page.click("//input[@value='Continue']");
  const pageText = await page.textContent("body");
  expect(pageText).toContain("Sydney to New York");
  
  await page.fill("input[name='passengerFirstName']", "Bob");
  await page.fill("input[name='passengerLastName']", "Tester");
  await page.click("//input[@value='Next']");
  expect(await page.locator("input[name='holder_name']").getAttribute("value")).toEqual("Bob Tester");
});



